
--[[
Copyright (c) 2014 Guy Mc Donald

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

Except as contained in this notice, the name of the above copyright holder
shall not be used in advertising or otherwise to promote the sale, use or
other dealings in this Software without prior written authorization.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHOR OR COPYRIGHT HOLDER BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
]]

local Digital = {}
local gr, floor, abs = love.graphics, math.floor, math.abs

function Digital.getTime()
	local h = os.date( '%H' )
	local m = os.date( '%M' )
	local s = os.date( '%S' )
	--local M = os.date( '%m' )
	--local D = os.date( '%d' )
	--local Y = os.date( '%Y' )
	return h,m,s
	end

function Digital.displayNumber( num, size, lx, ly )
	-- positive integer display only
	local num = tostring( abs( floor( num ) ) )
	local ss = size/3
	local sp = 100 * ss
	for i = 1, #num do
		Digital.draw( tonumber( string.sub( num, i, i) ), lx+sp*(i-1)+ss*42, ly+74*ss, ss )
		end
	end

function Digital.displayTime( h, m, s, size, lx, ly )
	-- hour, minute, second, digit size, location( x&y )
	local ss = size/3
	local sp = 100 * ss
	gr.setColor( 10, 10, 90 )
	gr.rectangle( 'fill', lx - 0.5 * sp, ly - sp, 7 * sp, 2 * sp )
	Digital.draw( string.sub( h, 1, 1), lx,				ly, ss )
	Digital.draw( string.sub( h, 2, 2), lx +       sp,	ly, ss )
	Digital.draw( string.sub( m, 1, 1), lx + 2.5 * sp,	ly, ss )
	Digital.draw( string.sub( m, 2, 2), lx + 3.5 * sp,	ly, ss )
	Digital.draw( string.sub( s, 1, 1), lx + 5   * sp,	ly, ss )
	Digital.draw( string.sub( s, 2, 2), lx + 6   * sp,	ly, ss )
	end

function Digital.load()
	Digital.show	= false
	local t,l = 32,64
	Digital.seg		= {{0,-l},{t,-t},{t,t},{0,l},{-t,t},{-t,-t},{0,0}} -- segment spacing
	Digital.orient	= {'h','v','v','h','v','v','h'}
	Digital.dis		= {		-- which segments to display number
		{1,1,1,1,1,1,0},	-- '0'
		{0,1,1,0,0,0,0},	-- '1'
		{1,1,0,1,1,0,1},	-- '2'
		{1,1,1,1,0,0,1},	-- '3'
		{0,1,1,0,0,1,1},	-- '4'
		{1,0,1,1,0,1,1},	-- '5'
		{1,0,1,1,1,1,1},	-- '6'
		{1,1,1,0,0,0,0},	-- '7'
		{1,1,1,1,1,1,1},	-- '8'
		{1,1,1,0,0,1,1}}	-- '9'
	end

function Digital.draw( num, lx, ly, sz )
	-- number, location of digit (x&y), digit size
	for i = 1, #Digital.seg do
		if Digital.dis[ num + 1 ][ i ] == 1 then
			mode = 'fill'
			gr.setColor( 255, 0, 0 )
			else
			mode = 'line'
			gr.setColor( 55, 55, 55 )
			end
		gr.polygon( mode, Digital.segment( Digital.orient[i], Digital.seg[i], lx, ly, sz ) )
		end
	end

function Digital.segment( orientation, seg, x, y, sz )
	--horizontal or verticle, segment location in digit, location of digit(x&y), segment size
	local ox, oy	= seg[1], seg[2]
	local sz		= sz or 1
	local a, b, c	= 10, 20, 30	-- segment's dimentions
	if orientation == 'h' then		-- horizontal segment
		return {
			sz * ( c + ox) + x,	sz * ( 0 + oy) + y,
			sz * ( b + ox) + x,	sz * (-a + oy) + y,
			sz * (-b + ox) + x,	sz * (-a + oy) + y,
			sz * (-c + ox) + x,	sz * ( 0 + oy) + y,
			sz * (-b + ox) + x,	sz * ( a + oy) + y,
			sz * ( b + ox) + x,	sz * ( a + oy) + y}
		else						-- verticle segment
		return {
			sz * ( 0 + ox) + x,	sz * (-c + oy) + y,
			sz * (-a + ox) + x,	sz * (-b + oy) + y,
			sz * (-a + ox) + x,	sz * ( b + oy) + y,
			sz * ( 0 + ox) + x,	sz * ( c + oy) + y,
			sz * ( a + ox) + x,	sz * ( b + oy) + y,
			sz * ( a + ox) + x,	sz * (-b + oy) + y}
		end
	end

return Digital
